
# Type: macromolecular machine_name




URI: [biolink:macromolecular_machine_name](https://w3id.org/biolink/vocab/macromolecular_machine_name)


## Domain and Range

[MacromolecularMachine](MacromolecularMachine.md) ->  <sub>REQ</sub> [SymbolType](types/SymbolType.md)

## Parents

 *  is_a: [name](name.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Gene](Gene.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [MicroRNA](MicroRNA.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
